==> apeman-app-recover-1.0.0.tgz: package/test/create_test.js <==
/**
 * Test case for create.
 * Runs with mocha.
 */
"use strict";

const create = require('../lib/create.js'),
    freeport = require('freeport'),
    apemanApp = require('apeman-app'),
    async = require('async'),
    fs = require('fs'),
    apemandb = require('apemandb'),
    request = require('request'),
    assert = require('assert');

let tmpDir = __dirname + '/../tmp',
    dbFile = tmpDir + '/testing-db01.db';

describe('create', () => {

    let db;
    let baseUrl;
    let close;
    let token01;
    let req = request.defaults({jar: true});

    before((done) => {
        db = apemandb({
            env: {
                DATABASE: 'testing-database02',
                USERNAME: 'FOO',
                PASSWORD: 'BAR',
                DIALECT: 'sqlite',
                STORAGE: dbFile,
                LOGGING: false
            },
            models: __dirname + '/../doc/mocks/models/*.json'
        });


        return db.sync({force: true})
            .then((db) => {
                done();
            });
    });

    before((done) => {
        let app = create(
            db.model('User'),
            db.model('Sign'),
            db.model('Recover'),
            {});
        assert.ok(app);
        freeport((err, port) => {
            assert.ifError(err);
            apemanApp('testing-app', {
                configuration: {
                    $apps: {
                        'testing-app': {
                            '/': [
                                require('apeman-app-json')(),
                                require('apeman-app-format')(),
                                require('apeman-app-send')(),
                                require('apeman-app-header')(),
                                require('apeman-app-form')(),
                                require('apeman-app-session')(
                                    db.model('Session'), '1234qwer'
                                ),
                                require('apeman-app-signed')()
                            ],
                            '/api/sign': require('apeman-app-sign')(
                                db.model('User'),
                                db.model('Sign')
                            ),
                            '/api/recover': app
                        }
                    }
                },
                port: port
            }, (err, server) => {
                assert.ifError(err);
                close = server.close.bind(server);
                baseUrl = 'http://localhost:' + port + '/';
                done(err);
            });
        });
    });

    after((done) => {
        close(()=> {
            setTimeout(() => {
                fs.unlink(dbFile, () => {
                    done();
                });
            }, 100); //Wait for flush.
        });
    });


    it('Send fail.', (done) => {
        req({
            url: baseUrl + 'api/recover/send',
            method: 'POST',
            form: {
                email: '__invalid_email___'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 404);
            done(err);
        });
    });

    it('signupSuccess', (done) => {
        req({
            url: baseUrl + 'api/sign/signup',
            method: 'POST',
            form: {
                username: 'user01',
                email: 'user01@exampole.com',
                password: 'user01_passwd'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data.success);
            assert.equal(data.signed[0].user_id, data.signed[1].user_id);
            done(err);
        })
    });

    it('Send success.', (done) => {
        req({
            url: baseUrl + 'api/recover/send',
            method: 'POST',
            form: {
                email: 'user01@exampole.com'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            let recover = data.recover;
            token01 = recover.recover_token;
            done(err);
        });
    });

    it('Reset fail.', (done) => {
        req({
            url: baseUrl + 'api/recover/reset',
            method: 'POST',
            form: {
                token: '__invalid_token__',
                password: 'hoge'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 404);
            let data = JSON.parse(body);
            assert.ok(data);
            done(err);
        });
    });

    it('Reset success.', (done) => {
        req({
            url: baseUrl + 'api/recover/reset',
            method: 'POST',
            form: {
                token: token01,
                password: 'new_password'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data);
            done(err);
        });
    });

    it('Signin with new password', (done) => {
        req({
            url: baseUrl + 'api/sign/signin',
            method: 'POST',
            form: {
                sign_key: 'user01',
                password: 'new_password'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data.success);
            assert.ok(data);
            done(err);
        })
    });

});

==> apeman-app-recover-2.1.1.tgz: package/test/create_test.js <==
/**
 * Test case for create.
 * Runs with mocha.
 */
"use strict";

const create = require('../lib/create.js'),
    freeport = require('freeport'),
    apemanApp = require('apeman-app'),
    async = require('async'),
    fs = require('fs'),
    apemandb = require('apemandb'),
    request = require('request'),
    assert = require('assert');

let tmpDir = __dirname + '/../tmp',
    dbFile = tmpDir + '/testing-db01.db';

describe('create', () => {

    let db;
    let baseUrl;
    let close;
    let token01;
    let req = request.defaults({jar: true});

    before((done) => {
        db = apemandb({
            env: {
                DATABASE: 'testing-database02',
                USERNAME: 'FOO',
                PASSWORD: 'BAR',
                DIALECT: 'sqlite',
                STORAGE: dbFile,
                LOGGING: false
            },
            models: __dirname + '/../doc/mocks/models/*.json'
        });


        return db.sync({force: true})
            .then((db) => {
                done();
            });
    });

    before((done) => {
        let app = create(
            db.model('UserRecover'),
            {});
        assert.ok(app);
        freeport((err, port) => {
            assert.ifError(err);
            apemanApp('testing-app', {
                configuration: {
                    $apps: {
                        'testing-app': {
                            '/': [
                                require('apeman-app-json')(),
                                require('apeman-app-format')(),
                                require('apeman-app-send')(),
                                require('apeman-app-header')(),
                                require('apeman-app-form')(),
                                require('apeman-app-session')(
                                    db.model('Session'), '1234qwer'
                                ),
                                require('apeman-app-signed')()
                            ],
                            '/api/sign': require('apeman-app-sign')(
                                db.model('UserSign')
                            ),
                            '/api/recover': app
                        }
                    }
                },
                port: port
            }, (err, server) => {
                assert.ifError(err);
                close = server.close.bind(server);
                baseUrl = 'http://localhost:' + port + '/';
                done(err);
            });
        });
    });

    after((done) => {
        close(()=> {
            setTimeout(() => {
                fs.unlink(dbFile, () => {
                    done();
                });
            }, 100); //Wait for flush.
        });
    });


    it('Send fail.', (done) => {
        req({
            url: baseUrl + 'api/recover/send',
            method: 'POST',
            form: {
                email: '__invalid_email___'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 404);
            done(err);
        });
    });

    it('Signup Success', (done) => {
        req({
            url: baseUrl + 'api/sign/signup',
            method: 'POST',
            form: {
                username: 'user01',
                email: 'user01@exampole.com',
                password: 'user01_passwd'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data.success);
            assert.equal(data.signed[0].user_id, data.signed[1].user_id);
            done(err);
        })
    });

    it('Send success.', (done) => {
        req({
            url: baseUrl + 'api/recover/send',
            method: 'POST',
            form: {
                email: 'user01@exampole.com'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            let recover = data.recover;
            token01 = recover.recover_token;
            done(err);
        });
    });

    it('Reset fail.', (done) => {
        req({
            url: baseUrl + 'api/recover/reset',
            method: 'POST',
            form: {
                token: '__invalid_token__',
                password: 'hoge'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 404);
            let data = JSON.parse(body);
            assert.ok(data);
            done(err);
        });
    });

    it('Reset success.', (done) => {
        req({
            url: baseUrl + 'api/recover/reset',
            method: 'POST',
            form: {
                token: token01,
                password: 'new_password'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data);
            done(err);
        });
    });

    it('Signin with new password', (done) => {
        req({
            url: baseUrl + 'api/sign/signin',
            method: 'POST',
            form: {
                sign_key: 'user01',
                password: 'new_password'
            }
        }, (err, res, body) => {
            assert.equal(res.statusCode, 200);
            let data = JSON.parse(body);
            assert.ok(data.success);
            assert.ok(data);
            done(err);
        })
    });

});
